@@ -11,7 +11,6 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 """Quota action implementations"""
 
@@ -20,7 +19,9 @@ import itertools
 import logging
 import sys
 
+from openstack import exceptions as sdk_exceptions
 from osc_lib.command import command
+from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
@@ -33,7 +34,6 @@ LOG = logging.getLogger(__name__)
 
 COMPUTE_QUOTAS = {
     'cores': 'cores',
-    'fixed_ips': 'fixed-ips',
     'injected_file_content_bytes': 'injected-file-size',
     'injected_file_path_bytes': 'injected-path-size',
     'injected_files': 'injected-files',
@@ -41,8 +41,8 @@ COMPUTE_QUOTAS = {
     'key_pairs': 'key-pairs',
     'metadata_items': 'properties',
     'ram': 'ram',
-    'server_groups': 'server-groups',
     'server_group_members': 'server-group-members',
+    'server_groups': 'server-groups',
 }
 
 VOLUME_QUOTAS = {
@@ -61,6 +61,7 @@ IMPACT_VOLUME_TYPE_QUOTAS = [
 ]
 
 NOVA_NETWORK_QUOTAS = {
+    'fixed_ips': 'fixed-ips',
     'floating_ips': 'floating-ips',
     'security_group_rules': 'secgroup-rules',
     'security_groups': 'secgroups',
@@ -104,11 +105,8 @@ def _xform_get_quota(data, value, keys):
 
 def get_project(app, project):
     if project is not None:
-        identity_client = app.client_manager.identity
-        project = utils.find_resource(
-            identity_client.projects,
-            project,
-        )
+        identity_client = app.client_manager.sdk_connection.identity
+        project = identity_client.find_project(project, ignore_missing=False)
         project_id = project.id
         project_name = project.name
     elif app.client_manager.auth_ref:
@@ -130,62 +128,55 @@ def get_compute_quotas(
     app,
     project_id,
     *,
-    quota_class=False,
     detail=False,
     default=False,
 ):
     try:
-        client = app.client_manager.compute
-        if quota_class:
-            # NOTE(stephenfin): The 'project' argument here could be anything
-            # as the nova API doesn't care what you pass in. We only pass the
-            # project in to avoid weirding people out :)
-            quota = client.quota_classes.get(project_id)
-        elif default:
-            quota = client.quotas.defaults(project_id)
+        client = app.client_manager.sdk_connection.compute
+        if default:
+            quota = client.get_quota_set_defaults(project_id)
         else:
-            quota = client.quotas.get(project_id, detail=detail)
-    except Exception as e:
-        if type(e).__name__ == 'EndpointNotFound':
-            return {}
-        raise
-    return quota._info
+            quota = client.get_quota_set(project_id, usage=detail)
+    except sdk_exceptions.EndpointNotFound:
+        return {}
+    data = quota.to_dict()
+    if not detail:
+        del data['usage']
+        del data['reservation']
+    return data
 
 
 def get_volume_quotas(
     app,
     project_id,
     *,
-    quota_class=False,
     detail=False,
     default=False,
 ):
     try:
-        client = app.client_manager.volume
-        if quota_class:
-            quota = client.quota_classes.get(project_id)
-        elif default:
-            quota = client.quotas.defaults(project_id)
+        client = app.client_manager.sdk_connection.volume
+        if default:
+            quota = client.get_quota_set_defaults(project_id)
         else:
-            quota = client.quotas.get(project_id, usage=detail)
-    except Exception as e:
-        if type(e).__name__ == 'EndpointNotFound':
-            return {}
-        else:
-            raise
-    return quota._info
+            quota = client.get_quota_set(project_id, usage=detail)
+    except sdk_exceptions.EndpointNotFound:
+        return {}
+    data = quota.to_dict()
+    if not detail:
+        del data['usage']
+        del data['reservation']
+    return data
 
 
 def get_network_quotas(
     app,
     project_id,
     *,
-    quota_class=False,
     detail=False,
     default=False,
 ):
     def _network_quota_to_dict(network_quota, detail=False):
-        if type(network_quota) is not dict:
+        if not isinstance(network_quota, dict):
             dict_quota = network_quota.to_dict()
         else:
             dict_quota = network_quota
@@ -207,11 +198,6 @@ def get_network_quotas(
 
         return result
 
-    # neutron doesn't have the concept of quota classes and if we're using
-    # nova-network we already fetched this
-    if quota_class:
-        return {}
-
     # we have nothing to return if we are not using neutron
     if not app.client_manager.is_network_endpoint_enabled():
         return {}
@@ -227,34 +213,14 @@ def get_network_quotas(
 
 
 class ListQuota(command.Lister):
-    _description = _(
-        "List quotas for all projects with non-default quota values or "
-        "list detailed quota information for requested project"
-    )
+    """List quotas for all projects with non-default quota values.
+
+    Empty output means all projects are using default quotas, which can be
+    inspected with 'openstack quota show --default'.
+    """
 
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
-        # TODO(stephenfin): Remove in OSC 8.0
-        parser.add_argument(
-            '--project',
-            metavar='<project>',
-            help=_(
-                "**Deprecated** List quotas for this project <project> "
-                "(name or ID). "
-                "Use 'quota show' instead."
-            ),
-        )
-        # TODO(stephenfin): Remove in OSC 8.0
-        parser.add_argument(
-            '--detail',
-            dest='detail',
-            action='store_true',
-            default=False,
-            help=_(
-                "**Deprecated** Show details about quotas usage. "
-                "Use 'quota show --usage' instead."
-            ),
-        )
         option = parser.add_mutually_exclusive_group(required=True)
         option.add_argument(
             '--compute',
@@ -276,64 +242,177 @@ class ListQuota(command.Lister):
         )
         return parser
 
-    def _get_detailed_quotas(self, parsed_args):
-        project_info = get_project(self.app, parsed_args.project)
-        project = project_info['id']
-
-        quotas = {}
-
-        if parsed_args.compute:
-            quotas.update(
-                get_compute_quotas(
-                    self.app,
-                    project,
-                    detail=parsed_args.detail,
-                )
-            )
-
-        if parsed_args.network:
-            quotas.update(
-                get_network_quotas(
-                    self.app,
-                    project,
-                    detail=parsed_args.detail,
-                )
-            )
-
-        if parsed_args.volume:
-            quotas.update(
-                get_volume_quotas(
-                    self.app,
-                    parsed_args,
-                    detail=parsed_args.detail,
-                ),
-            )
-
+    def _list_quota_compute(self, parsed_args, project_ids):
+        compute_client = self.app.client_manager.sdk_connection.compute
         result = []
-        for resource, values in quotas.items():
-            # NOTE(slaweq): there is no detailed quotas info for some resources
-            # and it shouldn't be displayed here
-            if isinstance(values, dict):
-                result.append(
-                    {
-                        'resource': resource,
-                        'in_use': values.get('in_use'),
-                        'reserved': values.get('reserved'),
-                        'limit': values.get('limit'),
-                    }
-                )
+
+        for project_id in project_ids:
+            try:
+                project_data = compute_client.get_quota_set(project_id)
+            except (
+                sdk_exceptions.NotFoundException,
+                sdk_exceptions.ForbiddenException,
+            ) as exc:
+                # Project not found, move on to next one
+                LOG.warning(f"Project {project_id} not found: {exc}")
+                continue
+
+            project_result = _xform_get_quota(
+                project_data,
+                project_id,
+                COMPUTE_QUOTAS.keys(),
+            )
+
+            default_data = compute_client.get_quota_set_defaults(project_id)
+            default_result = _xform_get_quota(
+                default_data,
+                project_id,
+                COMPUTE_QUOTAS.keys(),
+            )
+
+            if default_result != project_result:
+                result += project_result
 
         columns = (
-            'resource',
-            'in_use',
-            'reserved',
-            'limit',
+            'id',
+            'cores',
+            'injected_files',
+            'injected_file_content_bytes',
+            'injected_file_path_bytes',
+            'instances',
+            'key_pairs',
+            'metadata_items',
+            'ram',
+            'server_groups',
+            'server_group_members',
         )
         column_headers = (
-            'Resource',
-            'In Use',
-            'Reserved',
-            'Limit',
+            'Project ID',
+            'Cores',
+            'Injected Files',
+            'Injected File Content Bytes',
+            'Injected File Path Bytes',
+            'Instances',
+            'Key Pairs',
+            'Metadata Items',
+            'Ram',
+            'Server Groups',
+            'Server Group Members',
+        )
+        return (
+            column_headers,
+            (utils.get_dict_properties(s, columns) for s in result),
+        )
+
+    def _list_quota_volume(self, parsed_args, project_ids):
+        volume_client = self.app.client_manager.sdk_connection.volume
+        result = []
+
+        for project_id in project_ids:
+            try:
+                project_data = volume_client.get_quota_set(project_id)
+            except (
+                sdk_exceptions.NotFoundException,
+                sdk_exceptions.ForbiddenException,
+            ) as exc:
+                # Project not found, move on to next one
+                LOG.warning(f"Project {project_id} not found: {exc}")
+                continue
+
+            project_result = _xform_get_quota(
+                project_data,
+                project_id,
+                VOLUME_QUOTAS.keys(),
+            )
+
+            default_data = volume_client.get_quota_set_defaults(project_id)
+            default_result = _xform_get_quota(
+                default_data,
+                project_id,
+                VOLUME_QUOTAS.keys(),
+            )
+
+            if default_result != project_result:
+                result += project_result
+
+        columns = (
+            'id',
+            'backups',
+            'backup_gigabytes',
+            'gigabytes',
+            'per_volume_gigabytes',
+            'snapshots',
+            'volumes',
+        )
+        column_headers = (
+            'Project ID',
+            'Backups',
+            'Backup Gigabytes',
+            'Gigabytes',
+            'Per Volume Gigabytes',
+            'Snapshots',
+            'Volumes',
+        )
+
+        return (
+            column_headers,
+            (utils.get_dict_properties(s, columns) for s in result),
+        )
+
+    def _list_quota_network(self, parsed_args, project_ids):
+        network_client = self.app.client_manager.network
+        result = []
+
+        for project_id in project_ids:
+            try:
+                project_data = network_client.get_quota(project_id)
+            except (
+                sdk_exceptions.NotFoundException,
+                sdk_exceptions.ForbiddenException,
+            ) as exc:
+                # Project not found, move on to next one
+                LOG.warning(f"Project {project_id} not found: {exc}")
+                continue
+
+            project_result = _xform_get_quota(
+                project_data,
+                project_id,
+                NETWORK_KEYS,
+            )
+
+            default_data = network_client.get_quota_default(project_id)
+            default_result = _xform_get_quota(
+                default_data,
+                project_id,
+                NETWORK_KEYS,
+            )
+
+            if default_result != project_result:
+                result += project_result
+
+        columns = (
+            'id',
+            'floating_ips',
+            'networks',
+            'ports',
+            'rbac_policies',
+            'routers',
+            'security_groups',
+            'security_group_rules',
+            'subnets',
+            'subnet_pools',
+        )
+        column_headers = (
+            'Project ID',
+            'Floating IPs',
+            'Networks',
+            'Ports',
+            'RBAC Policies',
+            'Routers',
+            'Security Groups',
+            'Security Group Rules',
+            'Subnets',
+            'Subnet Pools',
         )
 
         return (
@@ -342,213 +421,18 @@ class ListQuota(command.Lister):
         )
 
     def take_action(self, parsed_args):
-        if parsed_args.detail:
-            msg = _(
-                "The --detail option has been deprecated. "
-                "Use 'openstack quota show --usage' instead."
-            )
-            self.log.warning(msg)
-        elif parsed_args.project:  # elif to avoid being too noisy
-            msg = _(
-                "The --project option has been deprecated. "
-                "Use 'openstack quota show' instead."
-            )
-            self.log.warning(msg)
-
-        result = []
-        project_ids = []
-        if parsed_args.project is None:
-            for p in self.app.client_manager.identity.projects.list():
-                project_ids.append(getattr(p, 'id', ''))
-        else:
-            identity_client = self.app.client_manager.identity
-            project = utils.find_resource(
-                identity_client.projects,
-                parsed_args.project,
-            )
-            project_ids.append(getattr(project, 'id', ''))
-
+        project_ids = [
+            p.id
+            for p in self.app.client_manager.sdk_connection.identity.projects()
+        ]
         if parsed_args.compute:
-            if parsed_args.detail:
-                return self._get_detailed_quotas(parsed_args)
-
-            compute_client = self.app.client_manager.compute
-            for p in project_ids:
-                try:
-                    data = compute_client.quotas.get(p)
-                except Exception as ex:
-                    if (
-                        type(ex).__name__ == 'NotFound'
-                        or ex.http_status >= 400
-                        and ex.http_status <= 499
-                    ):
-                        # Project not found, move on to next one
-                        LOG.warning("Project %s not found: %s" % (p, ex))
-                        continue
-                    else:
-                        raise
-
-                result_data = _xform_get_quota(
-                    data,
-                    p,
-                    COMPUTE_QUOTAS.keys(),
-                )
-                default_data = compute_client.quotas.defaults(p)
-                result_default = _xform_get_quota(
-                    default_data,
-                    p,
-                    COMPUTE_QUOTAS.keys(),
-                )
-                if result_default != result_data:
-                    result += result_data
-
-            columns = (
-                'id',
-                'cores',
-                'fixed_ips',
-                'injected_files',
-                'injected_file_content_bytes',
-                'injected_file_path_bytes',
-                'instances',
-                'key_pairs',
-                'metadata_items',
-                'ram',
-                'server_groups',
-                'server_group_members',
-            )
-            column_headers = (
-                'Project ID',
-                'Cores',
-                'Fixed IPs',
-                'Injected Files',
-                'Injected File Content Bytes',
-                'Injected File Path Bytes',
-                'Instances',
-                'Key Pairs',
-                'Metadata Items',
-                'Ram',
-                'Server Groups',
-                'Server Group Members',
-            )
-            return (
-                column_headers,
-                (utils.get_dict_properties(s, columns) for s in result),
-            )
-
-        if parsed_args.volume:
-            if parsed_args.detail:
-                return self._get_detailed_quotas(parsed_args)
-
-            volume_client = self.app.client_manager.volume
-            for p in project_ids:
-                try:
-                    data = volume_client.quotas.get(p)
-                except Exception as ex:
-                    if type(ex).__name__ == 'NotFound':
-                        # Project not found, move on to next one
-                        LOG.warning("Project %s not found: %s" % (p, ex))
-                        continue
-                    else:
-                        raise
-
-                result_data = _xform_get_quota(
-                    data,
-                    p,
-                    VOLUME_QUOTAS.keys(),
-                )
-                default_data = volume_client.quotas.defaults(p)
-                result_default = _xform_get_quota(
-                    default_data,
-                    p,
-                    VOLUME_QUOTAS.keys(),
-                )
-                if result_default != result_data:
-                    result += result_data
-
-            columns = (
-                'id',
-                'backups',
-                'backup_gigabytes',
-                'gigabytes',
-                'per_volume_gigabytes',
-                'snapshots',
-                'volumes',
-            )
-            column_headers = (
-                'Project ID',
-                'Backups',
-                'Backup Gigabytes',
-                'Gigabytes',
-                'Per Volume Gigabytes',
-                'Snapshots',
-                'Volumes',
-            )
-
-            return (
-                column_headers,
-                (utils.get_dict_properties(s, columns) for s in result),
-            )
-
-        if parsed_args.network:
-            if parsed_args.detail:
-                return self._get_detailed_quotas(parsed_args)
-
-            client = self.app.client_manager.network
-            for p in project_ids:
-                try:
-                    data = client.get_quota(p)
-                except Exception as ex:
-                    if type(ex).__name__ == 'NotFound':
-                        # Project not found, move on to next one
-                        LOG.warning("Project %s not found: %s" % (p, ex))
-                        continue
-                    else:
-                        raise
-
-                result_data = _xform_get_quota(
-                    data,
-                    p,
-                    NETWORK_KEYS,
-                )
-                default_data = client.get_quota_default(p)
-                result_default = _xform_get_quota(
-                    default_data,
-                    p,
-                    NETWORK_KEYS,
-                )
-                if result_default != result_data:
-                    result += result_data
-
-            columns = (
-                'id',
-                'floating_ips',
-                'networks',
-                'ports',
-                'rbac_policies',
-                'routers',
-                'security_groups',
-                'security_group_rules',
-                'subnets',
-                'subnet_pools',
-            )
-            column_headers = (
-                'Project ID',
-                'Floating IPs',
-                'Networks',
-                'Ports',
-                'RBAC Policies',
-                'Routers',
-                'Security Groups',
-                'Security Group Rules',
-                'Subnets',
-                'Subnet Pools',
-            )
-
-            return (
-                column_headers,
-                (utils.get_dict_properties(s, columns) for s in result),
-            )
+            return self._list_quota_compute(parsed_args, project_ids)
+        elif parsed_args.volume:
+            return self._list_quota_volume(parsed_args, project_ids)
+        elif parsed_args.network:
+            return self._list_quota_network(parsed_args, project_ids)
 
+        # will never get here
         return ((), ())
 
 
@@ -590,14 +474,19 @@ class SetQuota(common.NetDetectionMixin, command.Command):
         return rets
 
     def get_parser(self, prog_name):
-        parser = super(SetQuota, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'project',
             metavar='<project/class>',
-            help=_('Set quotas for this project or class (name or ID)'),
+            nargs='?',
+            help=_(
+                'Set quotas for this project or class (name or ID) '
+                '(defaults to current project)'
+            ),
         )
         # TODO(stephenfin): Remove in OSC 8.0
-        parser.add_argument(
+        type_group = parser.add_mutually_exclusive_group()
+        type_group.add_argument(
             '--class',
             dest='quota_class',
             action='store_true',
@@ -609,10 +498,17 @@ class SetQuota(common.NetDetectionMixin, command.Command):
                 '(compute and volume only)'
             ),
         )
+        type_group.add_argument(
+            '--default',
+            dest='default',
+            action='store_true',
+            default=False,
+            help=_('Set default quotas for <project>'),
+        )
         for k, v, h in self._build_options_list():
             parser.add_argument(
-                '--%s' % v,
-                metavar='<%s>' % v,
+                f'--{v}',
+                metavar=f'<{v}>',
                 dest=k,
                 type=int,
                 help=h,
@@ -627,22 +523,19 @@ class SetQuota(common.NetDetectionMixin, command.Command):
             '--force',
             action='store_true',
             dest='force',
-            # TODO(stephenfin): Change the default to False in Z or later
-            default=None,
+            default=False,
             help=_(
-                'Force quota update (only supported by compute and network) '
-                '(default for network)'
+                'Force quota update (only supported by compute and network)'
             ),
         )
         force_group.add_argument(
             '--no-force',
             action='store_false',
             dest='force',
-            default=None,
+            default=False,
             help=_(
                 'Do not force quota update '
-                '(only supported by compute and network) '
-                '(default for compute)'
+                '(only supported by compute and network) (default)'
             ),
         )
         # kept here for backwards compatibility/to keep the neutron folks happy
@@ -650,7 +543,7 @@ class SetQuota(common.NetDetectionMixin, command.Command):
             '--check-limit',
             action='store_false',
             dest='force',
-            default=None,
+            default=False,
             help=argparse.SUPPRESS,
         )
         return parser
@@ -662,67 +555,75 @@ class SetQuota(common.NetDetectionMixin, command.Command):
                 "never fully implemented and the compute and volume services "
                 "only support a single 'default' quota class while the "
                 "network service does not support quota classes at all. "
-                "Please use 'openstack quota show --default' instead."
+                "Please use 'openstack quota set --default' instead."
             )
             self.log.warning(msg)
 
-        identity_client = self.app.client_manager.identity
-        compute_client = self.app.client_manager.compute
-        volume_client = self.app.client_manager.volume
+        if (
+            parsed_args.quota_class or parsed_args.default
+        ) and parsed_args.force:
+            msg = _('--force cannot be used with --class or --default')
+            raise exceptions.CommandError(msg)
+
         compute_kwargs = {}
-        for k, v in COMPUTE_QUOTAS.items():
-            value = getattr(parsed_args, k, None)
-            if value is not None:
-                compute_kwargs[k] = value
-
-        if parsed_args.force is not None:
-            compute_kwargs['force'] = parsed_args.force
-
         volume_kwargs = {}
-        for k, v in VOLUME_QUOTAS.items():
-            value = getattr(parsed_args, k, None)
-            if value is not None:
-                if parsed_args.volume_type and k in IMPACT_VOLUME_TYPE_QUOTAS:
-                    k = k + '_%s' % parsed_args.volume_type
-                volume_kwargs[k] = value
-
         network_kwargs = {}
-        if parsed_args.force is True:
-            # Unlike compute, network doesn't provide a simple boolean option.
-            # Instead, it provides two options: 'force' and 'check_limit'
-            # (a.k.a. 'not force')
-            network_kwargs['force'] = True
-        elif parsed_args.force is False:
-            network_kwargs['check_limit'] = True
-        else:
-            msg = _(
-                "This command currently defaults to '--force' when modifying "
-                "network quotas. This behavior will change in a future "
-                "release. Consider explicitly providing '--force' or "
-                "'--no-force' options to avoid changes in behavior."
-            )
-            self.log.warning(msg)
+
+        if self.app.client_manager.is_compute_endpoint_enabled():
+            compute_client = self.app.client_manager.sdk_connection.compute
+
+            for k, v in COMPUTE_QUOTAS.items():
+                value = getattr(parsed_args, k, None)
+                if value is not None:
+                    compute_kwargs[k] = value
+
+            if compute_kwargs and parsed_args.force is True:
+                compute_kwargs['force'] = parsed_args.force
+
+        if self.app.client_manager.is_volume_endpoint_enabled():
+            volume_client = self.app.client_manager.sdk_connection.volume
+
+            for k, v in VOLUME_QUOTAS.items():
+                value = getattr(parsed_args, k, None)
+                if value is not None:
+                    if (
+                        parsed_args.volume_type
+                        and k in IMPACT_VOLUME_TYPE_QUOTAS
+                    ):
+                        k = k + f'_{parsed_args.volume_type}'
+                    volume_kwargs[k] = value
 
         if self.app.client_manager.is_network_endpoint_enabled():
+            network_client = self.app.client_manager.network
+
             for k, v in NETWORK_QUOTAS.items():
                 value = getattr(parsed_args, k, None)
                 if value is not None:
                     network_kwargs[k] = value
-        else:
+        elif self.app.client_manager.is_compute_endpoint_enabled():
             for k, v in NOVA_NETWORK_QUOTAS.items():
                 value = getattr(parsed_args, k, None)
                 if value is not None:
                     compute_kwargs[k] = value
 
-        if parsed_args.quota_class:
+        if network_kwargs:
+            if parsed_args.force is True:
+                # Unlike compute, network doesn't provide a simple boolean
+                # option. Instead, it provides two options: 'force' and
+                # 'check_limit' (a.k.a. 'not force')
+                network_kwargs['force'] = True
+            else:
+                network_kwargs['check_limit'] = True
+
+        if parsed_args.quota_class or parsed_args.default:
             if compute_kwargs:
-                compute_client.quota_classes.update(
-                    parsed_args.project,
+                compute_client.update_quota_class_set(
+                    parsed_args.project or 'default',
                     **compute_kwargs,
                 )
             if volume_kwargs:
-                volume_client.quota_classes.update(
-                    parsed_args.project,
+                volume_client.update_quota_class_set(
+                    parsed_args.project or 'default',
                     **volume_kwargs,
                 )
             if network_kwargs:
@@ -730,57 +631,40 @@ class SetQuota(common.NetDetectionMixin, command.Command):
                     "Network quotas are ignored since quota classes are not "
                     "supported."
                 )
-        else:
-            project = utils.find_resource(
-                identity_client.projects,
-                parsed_args.project,
-            ).id
 
-            if compute_kwargs:
-                compute_client.quotas.update(project, **compute_kwargs)
-            if volume_kwargs:
-                volume_client.quotas.update(project, **volume_kwargs)
-            if (
-                network_kwargs
-                and self.app.client_manager.is_network_endpoint_enabled()
-            ):
-                network_client = self.app.client_manager.network
-                network_client.update_quota(project, **network_kwargs)
+            return
+
+        project_info = get_project(self.app, parsed_args.project)
+        project = project_info['id']
+
+        if compute_kwargs:
+            compute_client.update_quota_set(project, **compute_kwargs)
+        if volume_kwargs:
+            volume_client.update_quota_set(project, **volume_kwargs)
+        if network_kwargs:
+            network_client.update_quota(project, **network_kwargs)
 
 
 class ShowQuota(command.Lister):
-    _description = _("""Show quotas for project or class.
+    _description = _(
+        """Show quotas for project or class.
 
 Specify ``--os-compute-api-version 2.50`` or higher to see ``server-groups``
-and ``server-group-members`` output for a given quota class.""")
+and ``server-group-members`` output for a given quota class."""
+    )
 
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument(
             'project',
-            metavar='<project/class>',
+            metavar='<project>',
             nargs='?',
             help=_(
-                'Show quotas for this project or class (name or ID) '
+                'Show quotas for this project (name or ID) '
                 '(defaults to current project)'
             ),
         )
         type_group = parser.add_mutually_exclusive_group()
-        # TODO(stephenfin): Remove in OSC 8.0
-        type_group.add_argument(
-            '--class',
-            dest='quota_class',
-            action='store_true',
-            default=False,
-            help=_(
-                '**Deprecated** Show quotas for <class>. '
-                'Deprecated as quota classes were never fully implemented '
-                'and only the default class is supported. '
-                'Use --default instead which is also supported by the network '
-                'service. '
-                '(compute and volume only)'
-            ),
-        )
         type_group.add_argument(
             '--default',
             dest='default',
@@ -832,20 +716,8 @@ and ``server-group-members`` output for a given quota class.""")
         return parser
 
     def take_action(self, parsed_args):
-        project = parsed_args.project
-
-        if parsed_args.quota_class:
-            msg = _(
-                "The '--class' option has been deprecated. Quota classes were "
-                "never fully implemented and the compute and volume services "
-                "only support a single 'default' quota class while the "
-                "network service does not support quota classes at all. "
-                "Please use 'openstack quota show --default' instead."
-            )
-            self.log.warning(msg)
-        else:
-            project_info = get_project(self.app, parsed_args.project)
-            project = project_info['id']
+        project_info = get_project(self.app, parsed_args.project)
+        project = project_info['id']
 
         compute_quota_info = {}
         volume_quota_info = {}
@@ -861,7 +733,6 @@ and ``server-group-members`` output for a given quota class.""")
                 self.app,
                 project,
                 detail=parsed_args.usage,
-                quota_class=parsed_args.quota_class,
                 default=parsed_args.default,
             )
         if parsed_args.service in {'all', 'volume'}:
@@ -869,7 +740,6 @@ and ``server-group-members`` output for a given quota class.""")
                 self.app,
                 project,
                 detail=parsed_args.usage,
-                quota_class=parsed_args.quota_class,
                 default=parsed_args.default,
             )
         if parsed_args.service in {'all', 'network'}:
@@ -877,7 +747,6 @@ and ``server-group-members`` output for a given quota class.""")
                 self.app,
                 project,
                 detail=parsed_args.usage,
-                quota_class=parsed_args.quota_class,
                 default=parsed_args.default,
             )
 
@@ -905,14 +774,24 @@ and ``server-group-members`` output for a given quota class.""")
         if 'id' in info:
             del info['id']
 
-        # Remove the 'location' field for resources from openstacksdk
-        if 'location' in info:
-            del info['location']
+        # Remove the sdk-derived fields
+        for field in ('location', 'name', 'force'):
+            if field in info:
+                del info[field]
 
         if not parsed_args.usage:
             result = [{'resource': k, 'limit': v} for k, v in info.items()]
         else:
-            result = [{'resource': k, **v} for k, v in info.items()]
+            result = [
+                {
+                    'resource': k,
+                    'limit': v or 0,
+                    'in_use': info['usage'].get(k, 0),
+                    'reserved': info['reservation'].get(k, 0),
+                }
+                for k, v in info.items()
+                if k not in ('usage', 'reservation')
+            ]
 
         columns = (
             'resource',
@@ -990,21 +869,20 @@ class DeleteQuota(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        identity_client = self.app.client_manager.identity
-        project = utils.find_resource(
-            identity_client.projects,
-            parsed_args.project,
+        identity_client = self.app.client_manager.sdk_connection.identity
+        project = identity_client.find_project(
+            parsed_args.project, ignore_missing=False
         )
 
         # compute quotas
         if parsed_args.service in {'all', 'compute'}:
-            compute_client = self.app.client_manager.compute
-            compute_client.quotas.delete(project.id)
+            compute_client = self.app.client_manager.sdk_connection.compute
+            compute_client.revert_quota_set(project.id)
 
         # volume quotas
         if parsed_args.service in {'all', 'volume'}:
-            volume_client = self.app.client_manager.volume
-            volume_client.quotas.delete(project.id)
+            volume_client = self.app.client_manager.sdk_connection.volume
+            volume_client.revert_quota_set(project.id)
 
         # network quotas (but only if we're not using nova-network, otherwise
         # we already deleted the quotas in the compute step)
