@@ -54,21 +54,20 @@ class ProjectColumn(cliff_columns.FormattableColumn):
 
 
 class CountColumn(cliff_columns.FormattableColumn):
-
     def human_readable(self):
         return len(self._value) if self._value is not None else None
 
 
 class FloatColumn(cliff_columns.FormattableColumn):
-
     def human_readable(self):
-        return float("%.2f" % self._value)
+        return float(f"{self._value:.2f}")
 
 
 def _formatters(project_cache):
     return {
         'project_id': functools.partial(
-            ProjectColumn, project_cache=project_cache),
+            ProjectColumn, project_cache=project_cache
+        ),
         'server_usages': CountColumn,
         'total_memory_mb_usage': FloatColumn,
         'total_vcpus_usage': FloatColumn,
@@ -110,24 +109,25 @@ class ListUsage(command.Lister):
     _description = _("List resource usage per project")
 
     def get_parser(self, prog_name):
-        parser = super(ListUsage, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "--start",
             metavar="<start>",
             default=None,
-            help=_("Usage range start date, ex 2012-01-20"
-                   " (default: 4 weeks ago)")
+            help=_(
+                "Usage range start date, ex 2012-01-20"
+                " (default: 4 weeks ago)"
+            ),
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)"),
         )
         return parser
 
     def take_action(self, parsed_args):
-
         def _format_project(project):
             if not project:
                 return ""
@@ -142,23 +142,23 @@ class ListUsage(command.Lister):
             "server_usages",
             "total_memory_mb_usage",
             "total_vcpus_usage",
-            "total_local_gb_usage"
+            "total_local_gb_usage",
         )
         column_headers = (
             "Project",
             "Servers",
             "RAM MB-Hours",
             "CPU Hours",
-            "Disk GB-Hours"
+            "Disk GB-Hours",
         )
 
         date_cli_format = "%Y-%m-%d"
-        date_api_format = "%Y-%m-%dT%H:%M:%S"
         now = datetime.datetime.utcnow()
 
         if parsed_args.start:
             start = datetime.datetime.strptime(
-                parsed_args.start, date_cli_format)
+                parsed_args.start, date_cli_format
+            )
         else:
             start = now - datetime.timedelta(weeks=4)
 
@@ -167,33 +167,41 @@ class ListUsage(command.Lister):
         else:
             end = now + datetime.timedelta(days=1)
 
-        usage_list = list(compute_client.usages(
-            start=start.strftime(date_api_format),
-            end=end.strftime(date_api_format),
-            detailed=True))
+        usage_list = list(
+            compute_client.usages(
+                start=start,
+                end=end,
+                detailed=True,
+            )
+        )
 
         # Cache the project list
         project_cache = {}
         try:
             for p in self.app.client_manager.identity.projects.list():
                 project_cache[p.id] = p
-        except Exception:
+        except Exception:  # noqa: S110
             # Just forget it if there's any trouble
             pass
 
         if parsed_args.formatter == 'table' and len(usage_list) > 0:
-            self.app.stdout.write(_("Usage from %(start)s to %(end)s: \n") % {
-                "start": start.strftime(date_cli_format),
-                "end": end.strftime(date_cli_format),
-            })
+            self.app.stdout.write(
+                _("Usage from %(start)s to %(end)s: \n")
+                % {
+                    "start": start.strftime(date_cli_format),
+                    "end": end.strftime(date_cli_format),
+                }
+            )
 
         return (
             column_headers,
             (
                 utils.get_item_properties(
-                    s, columns,
+                    s,
+                    columns,
                     formatters=_formatters(project_cache),
-                ) for s in usage_list
+                )
+                for s in usage_list
             ),
         )
 
@@ -202,25 +210,27 @@ class ShowUsage(command.ShowOne):
     _description = _("Show resource usage for a single project")
 
     def get_parser(self, prog_name):
-        parser = super(ShowUsage, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "--project",
             metavar="<project>",
             default=None,
-            help=_("Name or ID of project to show usage for")
+            help=_("Name or ID of project to show usage for"),
         )
         parser.add_argument(
             "--start",
             metavar="<start>",
             default=None,
-            help=_("Usage range start date, ex 2012-01-20"
-                   " (default: 4 weeks ago)")
+            help=_(
+                "Usage range start date, ex 2012-01-20"
+                " (default: 4 weeks ago)"
+            ),
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)"),
         )
         return parser
 
@@ -228,12 +238,12 @@ class ShowUsage(command.ShowOne):
         identity_client = self.app.client_manager.identity
         compute_client = self.app.client_manager.sdk_connection.compute
         date_cli_format = "%Y-%m-%d"
-        date_api_format = "%Y-%m-%dT%H:%M:%S"
         now = datetime.datetime.utcnow()
 
         if parsed_args.start:
             start = datetime.datetime.strptime(
-                parsed_args.start, date_cli_format)
+                parsed_args.start, date_cli_format
+            )
         else:
             start = now - datetime.timedelta(weeks=4)
 
@@ -252,33 +262,37 @@ class ShowUsage(command.ShowOne):
             project = self.app.client_manager.auth_ref.project_id
 
         usage = compute_client.get_usage(
-            project=project, start=start.strftime(date_api_format),
-            end=end.strftime(date_api_format))
+            project=project,
+            start=start,
+            end=end,
+        )
 
         if parsed_args.formatter == 'table':
-            self.app.stdout.write(_(
-                "Usage from %(start)s to %(end)s on project %(project)s: \n"
-            ) % {
-                "start": start.strftime(date_cli_format),
-                "end": end.strftime(date_cli_format),
-                "project": project,
-            })
+            self.app.stdout.write(
+                _("Usage from %(start)s to %(end)s on project %(project)s: \n")
+                % {
+                    "start": start.strftime(date_cli_format),
+                    "end": end.strftime(date_cli_format),
+                    "project": project,
+                }
+            )
 
         columns = (
             "project_id",
             "server_usages",
             "total_memory_mb_usage",
             "total_vcpus_usage",
-            "total_local_gb_usage"
+            "total_local_gb_usage",
         )
         column_headers = (
             "Project",
             "Servers",
             "RAM MB-Hours",
             "CPU Hours",
-            "Disk GB-Hours"
+            "Disk GB-Hours",
         )
 
         data = utils.get_item_properties(
-            usage, columns, formatters=_formatters(None))
+            usage, columns, formatters=_formatters(None)
+        )
         return column_headers, data
