@@ -31,6 +31,7 @@ from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.common import pagination
 from openstackclient.common import progressbar
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -162,6 +163,67 @@ def get_data_from_stdin():
         return None
 
 
+def _add_is_protected_args(parser):
+    protected_group = parser.add_mutually_exclusive_group()
+    protected_group.add_argument(
+        "--protected",
+        action="store_true",
+        dest="is_protected",
+        default=None,
+        help=_("Prevent image from being deleted"),
+    )
+    protected_group.add_argument(
+        "--unprotected",
+        action="store_false",
+        dest="is_protected",
+        default=None,
+        help=_("Allow image to be deleted (default)"),
+    )
+
+
+def _add_visibility_args(parser):
+    public_group = parser.add_mutually_exclusive_group()
+    public_group.add_argument(
+        "--public",
+        action="store_const",
+        const="public",
+        dest="visibility",
+        help=_("Image is accessible and visible to all users"),
+    )
+    public_group.add_argument(
+        "--private",
+        action="store_const",
+        const="private",
+        dest="visibility",
+        help=_(
+            "Image is only accessible by the owner "
+            "(default until --os-image-api-version 2.5)"
+        ),
+    )
+    public_group.add_argument(
+        "--community",
+        action="store_const",
+        const="community",
+        dest="visibility",
+        help=_(
+            "Image is accessible by all users but does not appear in the "
+            "default image list of any user except the owner "
+            "(requires --os-image-api-version 2.5 or later)"
+        ),
+    )
+    public_group.add_argument(
+        "--shared",
+        action="store_const",
+        const="shared",
+        dest="visibility",
+        help=_(
+            "Image is only accessible by the owner and image members "
+            "(requires --os-image-api-version 2.5 or later) "
+            "(default since --os-image-api-version 2.5)"
+        ),
+    )
+
+
 class AddProjectToImage(command.ShowOne):
     _description = _("Associate project with image")
 
@@ -321,50 +383,8 @@ class CreateImage(command.ShowOne):
                 "Only use in combination with --sign-key-path"
             ),
         )
-        protected_group = parser.add_mutually_exclusive_group()
-        protected_group.add_argument(
-            "--protected",
-            action="store_true",
-            dest="is_protected",
-            default=None,
-            help=_("Prevent image from being deleted"),
-        )
-        protected_group.add_argument(
-            "--unprotected",
-            action="store_false",
-            dest="is_protected",
-            default=None,
-            help=_("Allow image to be deleted (default)"),
-        )
-        public_group = parser.add_mutually_exclusive_group()
-        public_group.add_argument(
-            "--public",
-            action="store_const",
-            const="public",
-            dest="visibility",
-            help=_("Image is accessible to the public"),
-        )
-        public_group.add_argument(
-            "--private",
-            action="store_const",
-            const="private",
-            dest="visibility",
-            help=_("Image is inaccessible to the public (default)"),
-        )
-        public_group.add_argument(
-            "--community",
-            action="store_const",
-            const="community",
-            dest="visibility",
-            help=_("Image is accessible to the community"),
-        )
-        public_group.add_argument(
-            "--shared",
-            action="store_const",
-            const="shared",
-            dest="visibility",
-            help=_("Image can be shared"),
-        )
+        _add_is_protected_args(parser)
+        _add_visibility_args(parser)
         parser.add_argument(
             "--property",
             dest="properties",
@@ -401,8 +421,8 @@ class CreateImage(command.ShowOne):
         identity_common.add_project_domain_option_to_parser(parser)
         for deadopt in self.deadopts:
             parser.add_argument(
-                "--%s" % deadopt,
-                metavar="<%s>" % deadopt,
+                f"--{deadopt}",
+                metavar=f"<{deadopt}>",
                 dest=deadopt.replace('-', '_'),
                 help=argparse.SUPPRESS,
             )
@@ -468,7 +488,7 @@ class CreateImage(command.ShowOne):
                 fp = open(parsed_args.filename, 'rb')
             except FileNotFoundError:
                 raise exceptions.CommandError(
-                    '%r is not a valid file' % parsed_args.filename,
+                    f'{parsed_args.filename!r} is not a valid file',
                 )
         else:
             fp = get_data_from_stdin()
@@ -506,8 +526,8 @@ class CreateImage(command.ShowOne):
                 raise exceptions.CommandError(msg)
 
             if (
-                len(parsed_args.sign_key_path) < 1 or
-                len(parsed_args.sign_cert_id) < 1
+                len(parsed_args.sign_key_path) < 1
+                or len(parsed_args.sign_cert_id) < 1
             ):
                 msg = _(
                     "'sign-key-path' and 'sign-cert-id' must both be "
@@ -596,10 +616,7 @@ class CreateImage(command.ShowOne):
         )
         kwargs = {}
         if volume_client.api_version < api_versions.APIVersion('3.1'):
-            if (
-                parsed_args.visibility or
-                parsed_args.is_protected is not None
-            ):
+            if parsed_args.visibility or parsed_args.is_protected is not None:
                 msg = _(
                     '--os-volume-api-version 3.1 or greater is required '
                     'to support the --public, --private, --community, '
@@ -618,7 +635,7 @@ class CreateImage(command.ShowOne):
             parsed_args.name,
             parsed_args.container_format,
             parsed_args.disk_format,
-            **kwargs
+            **kwargs,
         )
         info = body['os-volume_upload_image']
         try:
@@ -656,11 +673,17 @@ class DeleteImage(command.Command):
             nargs="+",
             help=_("Image(s) to delete (name or ID)"),
         )
+        parser.add_argument(
+            '--store',
+            metavar='<STORE>',
+            # default=None,
+            dest='store',
+            help=_('Store to delete image(s) from.'),
+        )
         return parser
 
     def take_action(self, parsed_args):
-
-        del_result = 0
+        result = 0
         image_client = self.app.client_manager.image
         for image in parsed_args.images:
             try:
@@ -668,9 +691,16 @@ class DeleteImage(command.Command):
                     image,
                     ignore_missing=False,
                 )
-                image_client.delete_image(image_obj.id)
+                image_client.delete_image(
+                    image_obj.id,
+                    store=parsed_args.store,
+                    ignore_missing=False,
+                )
+            except sdk_exceptions.ResourceNotFound:
+                msg = _("Multi Backend support not enabled.")
+                raise exceptions.CommandError(msg)
             except Exception as e:
-                del_result += 1
+                result += 1
                 msg = _(
                     "Failed to delete image with name or "
                     "ID '%(image)s': %(e)s"
@@ -678,9 +708,9 @@ class DeleteImage(command.Command):
                 LOG.error(msg, {'image': image, 'e': e})
 
         total = len(parsed_args.images)
-        if del_result > 0:
-            msg = _("Failed to delete %(dresult)s of %(total)s images.") % {
-                'dresult': del_result,
+        if result > 0:
+            msg = _("Failed to delete %(result)s of %(total)s images.") % {
+                'result': result,
                 'total': total,
             }
             raise exceptions.CommandError(msg)
@@ -711,14 +741,20 @@ class ListImage(command.Lister):
             action="store_const",
             const="community",
             dest="visibility",
-            help=_("List only community images"),
+            help=_(
+                "List only community images "
+                "(requires --os-image-api-version 2.5 or later)"
+            ),
         )
         public_group.add_argument(
             "--shared",
             action="store_const",
             const="shared",
             dest="visibility",
-            help=_("List only shared images"),
+            help=_(
+                "List only shared images "
+                "(requires --os-image-api-version 2.5 or later)"
+            ),
         )
         public_group.add_argument(
             "--all",
@@ -791,9 +827,9 @@ class ListImage(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
-
         # --page-size has never worked, leave here for silent compatibility
         # We'll implement limit/marker differently later
+        # TODO(stephenfin): Remove this in the next major version bump
         parser.add_argument(
             "--page-size",
             metavar="<size>",
@@ -809,22 +845,7 @@ class ListImage(command.Lister):
                 "specified separated by comma"
             ),
         )
-        parser.add_argument(
-            "--limit",
-            metavar="<num-images>",
-            type=int,
-            help=_("Maximum number of images to display."),
-        )
-        parser.add_argument(
-            '--marker',
-            metavar='<image>',
-            default=None,
-            help=_(
-                "The last image of the previous page. Display "
-                "list of images after marker. Display all images if not "
-                "specified. (name or ID)"
-            ),
-        )
+        pagination.add_marker_pagination_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
@@ -992,6 +1013,43 @@ class RemoveProjectImage(command.Command):
         image_client.remove_member(member=project_id, image=image.id)
 
 
+class ShowProjectImage(command.ShowOne):
+    _description = _("Show a particular project associated with image")
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            "image",
+            metavar="<image>",
+            help=_("Image (name or ID)"),
+        )
+        parser.add_argument(
+            "member",
+            metavar="<project>",
+            help=_("Project to show (name or ID)"),
+        )
+        identity_common.add_project_domain_option_to_parser(parser)
+        return parser
+
+    def take_action(self, parsed_args):
+        image_client = self.app.client_manager.image
+
+        image = image_client.find_image(
+            parsed_args.image,
+            ignore_missing=False,
+        )
+
+        obj = image_client.get_member(
+            image=image.id,
+            member=parsed_args.member,
+        )
+
+        display_columns, columns = _get_member_columns(obj)
+        data = utils.get_item_properties(obj, columns, formatters={})
+
+        return (display_columns, data)
+
+
 class SaveImage(command.Command):
     _description = _("Save an image locally")
 
@@ -1073,50 +1131,8 @@ class SetImage(command.Command):
             help=_("Image disk format. The supported options are: %s")
             % ', '.join(DISK_CHOICES),
         )
-        protected_group = parser.add_mutually_exclusive_group()
-        protected_group.add_argument(
-            "--protected",
-            action="store_true",
-            dest="is_protected",
-            default=None,
-            help=_("Prevent image from being deleted"),
-        )
-        protected_group.add_argument(
-            "--unprotected",
-            action="store_false",
-            dest="is_protected",
-            default=None,
-            help=_("Allow image to be deleted (default)"),
-        )
-        public_group = parser.add_mutually_exclusive_group()
-        public_group.add_argument(
-            "--public",
-            action="store_const",
-            const="public",
-            dest="visibility",
-            help=_("Image is accessible to the public"),
-        )
-        public_group.add_argument(
-            "--private",
-            action="store_const",
-            const="private",
-            dest="visibility",
-            help=_("Image is inaccessible to the public (default)"),
-        )
-        public_group.add_argument(
-            "--community",
-            action="store_const",
-            const="community",
-            dest="visibility",
-            help=_("Image is accessible to the community"),
-        )
-        public_group.add_argument(
-            "--shared",
-            action="store_const",
-            const="shared",
-            dest="visibility",
-            help=_("Image can be shared"),
-        )
+        _add_is_protected_args(parser)
+        _add_visibility_args(parser)
         parser.add_argument(
             "--property",
             dest="properties",
@@ -1193,8 +1209,8 @@ class SetImage(command.Command):
         identity_common.add_project_domain_option_to_parser(parser)
         for deadopt in self.deadopts:
             parser.add_argument(
-                "--%s" % deadopt,
-                metavar="<%s>" % deadopt,
+                f"--{deadopt}",
+                metavar=f"<{deadopt}>",
                 dest=f"dead_{deadopt.replace('-', '_')}",
                 help=argparse.SUPPRESS,
             )
@@ -1559,7 +1575,7 @@ class StageImage(command.Command):
                 fp = open(parsed_args.filename, 'rb')
             except FileNotFoundError:
                 raise exceptions.CommandError(
-                    '%r is not a valid file' % parsed_args.filename,
+                    f'{parsed_args.filename!r} is not a valid file',
                 )
         else:
             fp = get_data_from_stdin()
@@ -1598,8 +1614,6 @@ class ImportImage(command.ShowOne):
             metavar='<image>',
             help=_('Image to initiate import process for (name or ID)'),
         )
-        # TODO(stephenfin): Uncomment help text when we have this command
-        # implemented
         parser.add_argument(
             '--method',
             metavar='<method>',
@@ -1614,8 +1628,6 @@ class ImportImage(command.ShowOne):
             help=_(
                 "Import method used for image import process. "
                 "Not all deployments will support all methods. "
-                # "Valid values can be retrieved with the 'image import "
-                # "methods' command. "
                 "The 'glance-direct' method (default) requires images be "
                 "first staged using the 'image-stage' command."
             ),
@@ -1718,11 +1730,15 @@ class ImportImage(command.ShowOne):
 
         if parsed_args.import_method not in import_methods:
             msg = _(
-                "The '%s' import method is not supported by this deployment. "
-                "Supported: %s"
+                "The '%(method)s' import method is not supported by this "
+                "deployment. Supported: %(supported)s"
             )
             raise exceptions.CommandError(
-                msg % (parsed_args.import_method, ', '.join(import_methods)),
+                msg
+                % {
+                    'method': parsed_args.import_method,
+                    'supported': ', '.join(import_methods),
+                },
             )
 
         if parsed_args.import_method == 'web-download':
@@ -1777,7 +1793,9 @@ class ImportImage(command.ShowOne):
                 )
                 raise exceptions.CommandError(msg)
 
-        image = image_client.find_image(parsed_args.image)
+        image = image_client.find_image(
+            parsed_args.image, ignore_missing=False
+        )
 
         if not image.container_format and not image.disk_format:
             msg = _(
@@ -1813,7 +1831,7 @@ class ImportImage(command.ShowOne):
             method=parsed_args.import_method,
             uri=parsed_args.uri,
             remote_region=parsed_args.remote_region,
-            remote_image=parsed_args.remote_image,
+            remote_image_id=parsed_args.remote_image,
             remote_service_interface=parsed_args.remote_service_interface,
             stores=parsed_args.stores,
             all_stores=parsed_args.all_stores,
@@ -1822,3 +1840,48 @@ class ImportImage(command.ShowOne):
 
         info = _format_image(image)
         return zip(*sorted(info.items()))
+
+
+class StoresInfo(command.Lister):
+    _description = _(
+        "Get available backends (only valid with Multi-Backend support)"
+    )
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            "--detail",
+            action='store_true',
+            default=None,
+            help=_(
+                'Shows details of stores (admin only) '
+                '(requires --os-image-api-version 2.15 or later)'
+            ),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        image_client = self.app.client_manager.image
+        try:
+            columns = ("id", "description", "is_default")
+            column_headers = ("ID", "Description", "Default")
+            if parsed_args.detail:
+                columns += ("properties",)
+                column_headers += ("Properties",)
+
+            data = list(image_client.stores(details=parsed_args.detail))
+        except sdk_exceptions.ResourceNotFound:
+            msg = _('Multi Backend support not enabled')
+            raise exceptions.CommandError(msg)
+        else:
+            return (
+                column_headers,
+                (
+                    utils.get_item_properties(
+                        store,
+                        columns,
+                        formatters=_formatters,
+                    )
+                    for store in data
+                ),
+            )
