@@ -20,9 +20,8 @@ from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 
 
 class TestToken(identity_fakes.TestIdentityv3):
-
     def setUp(self):
-        super(TestToken, self).setUp()
+        super().setUp()
 
         # Get a shortcut to the Auth Ref Mock
         self.ar_mock = mock.PropertyMock()
@@ -30,9 +29,8 @@ class TestToken(identity_fakes.TestIdentityv3):
 
 
 class TestTokenIssue(TestToken):
-
     def setUp(self):
-        super(TestTokenIssue, self).setUp()
+        super().setUp()
 
         self.cmd = token.IssueToken(self.app, None)
 
@@ -117,12 +115,11 @@ class TestTokenIssue(TestToken):
 
 
 class TestTokenRevoke(TestToken):
-
     TOKEN = 'fob'
 
     def setUp(self):
-        super(TestTokenRevoke, self).setUp()
-        self.tokens_mock = self.app.client_manager.identity.tokens
+        super().setUp()
+        self.tokens_mock = self.identity_client.tokens
         self.tokens_mock.reset_mock()
         self.tokens_mock.revoke_token.return_value = True
         self.cmd = token.RevokeToken(self.app, None)
